#
# spec file for package gsl
#
# Copyright (c) 2013 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           gsl
#BuildRequires:  blas latex2html
BuildRequires:  blas
%if 0%{?suse_version}
BuildRequires:  libtool
%endif
BuildRequires:  pkgconfig
%if 0%{?fedora_version}
Requires:       info
%endif
Version:        1.16
Release:        8.4
# NOTE: The package has been update to 1.10+ after all issues with
# GNU GPLv3 have been resolved.
Summary:        GNU Scientific Library
License:        GPL-3.0+
Group:          Development/Libraries/C and C++
Source:         ftp://ftp.gnu.org/pub/gnu/gsl/gsl-%{version}.tar.gz
Patch:          gsl-1.6-initvars.diff
Patch5:         gsl-wrap.diff
Patch6:         gsl-qawc-test-x86-precision.diff
Patch7:         gsl-disable-fma.patch
Patch8:         gsl-fsf_address.patch
Url:            http://www.gnu.org/software/gsl/
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
The GNU Scientific Library (GSL) is a collection of routines for
numerical computing. The routines are written from scratch by the GSL
team in ANSI C and present a modern Applications Programming Interface
(API) for C programmers, while allowing wrappers to be written for very
high level languages.

The library covers the following areas:

Complex Numbers - Roots of Polynomials - Special Functions - 
Vectors and Matrices - Permutations - Sorting - BLAS Support -
Linear Algebra - Eigensystems - Fast Fourier Transforms - Quadrature - 
Random Numbers - Quasi-Random Sequences - Random Distributions - 
Statistics - Histograms - N-Tuples - Monte Carlo Integration - 
Simulated Annealing - Differential Equations - Interpolation - 
Numerical Differentiation - Chebyshev Approximation - Series Acceleration - 
Discrete Hankel Transforms - Root-Finding - Minimization - 
Least-Squares Fitting - Physical Constants - IEEE Floating-Point

%package        devel
Summary:        GNU Scientific Library - development files
License:        GPL-2.0+
Group:          Development/Libraries/C and C++
Requires:       glibc-devel
Requires:       gsl = %{version}
%if 0%{?suse_version}
PreReq:         %{install_info_prereq}
%endif

%description devel
This package contains the headers, static libraries and some
documentation for GSL.

The GNU Scientific Library (GSL) is a collection of routines for
numerical computing. The routines are written from scratch by the GSL
team in ANSI C, and present a modern Applications Programming Interface
(API) for C programmers, while allowing wrappers to be written for very
high level languages.

The library covers the following areas,

Complex Numbers - Roots of Polynomials - Special Functions - 
Vectors and Matrices - Permutations - Sorting - BLAS Support -
Linear Algebra - Eigensystems - Fast Fourier Transforms - Quadrature - 
Random Numbers - Quasi-Random Sequences - Random Distributions - 
Statistics - Histograms - N-Tuples - Monte Carlo Integration - 
Simulated Annealing - Differential Equations - Interpolation - 
Numerical Differentiation - Chebyshev Approximation - Series Acceleration - 
Discrete Hankel Transforms - Root-Finding - Minimization - 
Least-Squares Fitting - Physical Constants - IEEE Floating-Point

%prep
%setup -q
%patch -p1
%patch5 -p1
%patch6 
%patch7 -p1
%patch8

%build
autoreconf -fi
RPM_OPT_FLAGS=`echo "$RPM_OPT_FLAGS" | sed 's/-fstack-protector//'`
#export CFLAGS="%%{optflags} -fno-strict-aliasing"
export CFLAGS="%{optflags}"
%configure --disable-static --with-pic --enable-shared --with-gnu-ld
make %{?_smp_mflags}
# latex2html (dvips) is braindead in its rejection of '.' in a dir name
# the following fails right now, disable it:
#cd ..
#mv %%{name}-%%{version} %%{name}
#cd %%{name}/doc
#texi2html -l2h -menu -split_chapter -glossary gsl-ref.texi
#cd ../..
#mv %%{name} %{name}-%%{version}

%check
%if ! 0%{?qemu_user_space_build}
make %{?_smp_mflags} check || true
%endif

%install
%makeinstall
%{__rm} -f %{buildroot}%{_libdir}/*.la
%{__rm} -f %{buildroot}%{_infodir}/dir

%post -p /sbin/ldconfig

%postun -p /sbin/ldconfig

%files
%defattr(-,root,root)
%{_libdir}/libgsl*.so.*
%{_bindir}/gsl-histogram
%{_bindir}/gsl-randist
%doc %{_mandir}/man1/gsl-histogram.1.gz
%doc %{_mandir}/man1/gsl-randist.1.gz
%doc AUTHORS BUGS COPYING ChangeLog NEWS README THANKS TODO

%files devel
%defattr(-,root,root)
%{_includedir}/gsl
%{_libdir}/libgsl*.so
%{_libdir}/pkgconfig/gsl.pc
%{_bindir}/gsl-config
#%%doc doc/gsl-ref/gsl-ref*.html
%{_datadir}/aclocal/gsl.m4
%doc %{_infodir}/gsl-ref*
%doc %{_mandir}/man1/gsl-config.1.gz
%doc %{_mandir}/man3/gsl.3.gz

%post devel
%install_info --info-dir=%{_infodir} %{_infodir}/gsl-ref.info.gz

%postun devel
%install_info_delete --info-dir=%{_infodir} %{_infodir}/gsl-ref.info.gz

%changelog
* Mon Sep  9 2013 badshah400@gmail.com
- Update to version 1.16:
  + fixed error in gsl_rng_fwrite where uninitialized padding
    bytes were being written (bug #39104)
  + fixed error in gsl_block_alloc where padding bytes were not
    properly initialized (bugs #39101,#39102,#39103)
  + fixed error in ntuple/test.c where padding bytes were not
    properly initialized (bug #39105)
  + fixed triangle selection bug in gsl_sf_coupling_6j_e and
    gsl_sf_coupling_9j_e (bugs #39466 and #29606)
  + added higher level wrapper routine
    gsl_multifit_fdfsolver_driver
  + converted gsl_multifit_linear_residuals to use dgemv to
    improve efficiency (bug #39153)
  + added functions gsl_stats_spearman and gsl_sort_vector2 to
    compute Spearman rank correlation
  + added function gsl_poly_dd_hermite_init for Hermite
    interpolation
  + Added support for robust linear least squares
  + Added function gsl_linalg_SV_leverage for computing
    statistical leverages from SVD decomposition
  + Added support for approximating the Jacobian of nonlinear least
    squares fits using forward finite differences
  + Extended gsl_sf_coupling_3j to allow larger range and to
    handle the special case (ja jb jc; 0 0 0)=0 when ja+jb+jc is
    odd
  + Fixed gsl_sf_mathieu_se_array to return zero when the order is
    zero [bug #33679]
  + Fixed overflow in gsl_sf_lncosh for large negative x (x<-354)
  + Improved gsl_ran_negative_binomial_pdf to avoid
    underflow/overflow for large arguments
  + Multisets now allow k strictly greater than n
  + Fixed gsl_matrix_complex_fwrite/fread failure for
    noncontiguous matrices
* Fri Jun 29 2012 coolo@suse.com
- the buildrequire for specific gcc libraries seems unneeded (and broke)
* Wed Mar 28 2012 pth@suse.de
- Remove the unneccessary -fno-strict-aliasing.
- Replace FSF address in headers by link to the FSF licenses web
  page.
- prefix all patch files with a 'gsl-'
* Tue Feb 28 2012 idonmez@suse.com
- Disable FMA support, see the following message for details:
  http://lists.gnu.org/archive/html/bug-gsl/2011-11/msg00019.html
- Still disable %%check on i586 because it fails.
* Sat Feb  4 2012 jengelh@medozas.de
- Remove redundant tags/sections (see specfile guidelines)
- Parallel build with %%_smp_mflags
* Sat Feb  4 2012 jengelh@medozas.de
- Remove redundant tags/sections (see specfile guidelines)
* Sat Oct 15 2011 coolo@suse.com
- add libtool as buildrequire to make the spec file more reliable
* Sat Oct  1 2011 crrodriguez@opensuse.org
- Workaround qemu-arm bugs.
* Thu Sep 29 2011 andrea.turrini@gmail.com
- Made descriptions in gls.spec more readable
* Sun Jul 17 2011 badshah400@gmail.com
- Update to 1.15: New functions, improvements and bug-fixes; see
  NEWS for full list
* Wed Dec  8 2010 kkaempf@novell.com
- Update to 1.14
  Bugfixes, improvements and new functions. See NEWS for full list.
* Mon Dec  6 2010 kkaempf@novell.com
- Fix build on non-SUSE distros
* Mon Dec  6 2010 kkaempf@novell.com
- Add pkg-config to BuildRequires so pkgconfig(gsl) gets created
  as provides of the -devel package
* Thu Feb 11 2010 rguenther@suse.de
- Drop all fancy compile flags as long as we need -fno-strict-aliasing.
* Thu Jul 30 2009 garloff@suse.de
- Run make check on all archs, relax precision for qawc elist on x86.
* Thu Jul 30 2009 aj@suse.de
- Update to gsl-1.12:
  * Many bugfixes (see NEWS for full list)
  * Improvements: faster simplex mininimser gsl_multimin_fminimizer_nmsimplex2,
    gsl_monte_vegas to avoid catastrophic cancellation,
  * New functions: gsl_bspline_eval_deriv, new auxiliary functions
    gsl_cheb_order, gsl_cheb_size, gsl_cheb_coeffs for Chebyshev series,
    gsl_vector_complex_{isnonneg,add,sub,mul, div,scale,add_constant}
    and gsl_matrix_complex_float_isnonn, gsl_linalg_cholesky_invert
* Tue Jul 28 2009 aj@suse.de
- Fix build - disable html generation which fails.
* Tue Jan 13 2009 crrodriguez@suse.de
- remove static libraries and "la" files
* Fri Aug 22 2008 garloff@suse.de
- Update to gsl-1.11:
  * Bugfixes (underflow in ODE solver, overflow in
    gsl_cdf_hypergeometric_{P,Q}, brent_minimiser)
  * Improvements (asymptotic regime in gsl_sf_bessel_jl,
    large arguments in cum. distr. functions using incomplete beta
    function, missing error terms in gsl_sf_exp_mult_e10_e,
    gsl_sf_hyperg_2F1 now handles x==1, gsl_ldexp and gsl_frexp,
    gsl_multiroots_test_delta)
  * Optimizations in gsl_ran_gaussian_ziggurat.
  * New function gsl_multifit_linear_residuals.
  * Updated some constants to match CODATA 2006 values.
- Update to gsl-1.10:
  * The package license changed from GNU GPL v2 or later to
    GNU GPL v3 or later!
  * Support for generalized eigensystems.
  * gsl_stats_correlation computes Pearson correlation of two data sets
  * New functions: gsl_sf_expint(n,x), gsl_{vector,matrix}_isnonneg,
    gsl_matrix_sub{row,column}
  * Cholesky routines now handle complex matrices
  * Many other improvements and additions, see NEWS for a detailed list.
* Wed Nov  7 2007 garloff@suse.de
- disable -fstack-protector (we don't want it for HPC code)
- avoid wrapping assumption sort testcase (gcc-4.3 fix)
- move make check to %%check section
- require gsl = %%{version} from -devel package
- call install-info in -devel %%post/%%postun
- add note on license
* Mon Apr 16 2007 dmueller@suse.de
- run autoreconf
- fix devel package requires
- run ldconfig
* Tue Mar 13 2007 garloff@suse.de
- Update to gsl-1.9:
  * Fixed the elliptic integrals F,E,P,D so that they have the
    correct behavior for phi > pi/2 and phi < 0.
  * New BFGS minimisation method gsl_multimin_fdfminimizer_vector_bfgs2
    based on the algorithm given by R.Fletcher in "Practical Methods
    of Optimisation" (2nd ed).
  * Beta functions gsl_sf_beta_e(a,b) and gsl_sf_lnbeta_e(a,b) now
    handle negative arguments a,b. New function gsl_sf_lnbeta_sgn_e
    for computing magnitude and sign of negative beta values.
  * gsl_cheb_eval_mode now uses the same error estimate as
    gsl_cheb_eval_err.
  * Improved gsl_sf_legendre_sphPlm_e to avoid underflow with large
    arguments.
  * Added updated Knuth generator, gsl_rng_knuthran2002, from 9th
    printing of "The Art of Computer Programming". See
    http://www-cs-faculty.stanford.edu/~knuth/news02.htm
  * The functions gsl_multifit_fsolver_set, gsl_multifit_fdfsolver_set
    and gsl_multiroot_fsolver_set, gsl_multiroot_fdfsolver_set now
    have a const qualifier for the input vector x.
  * gsl_sf_expint_E2(x) now returns the correct value 1 for x==0,
    instead of NaN.
  * The gsl_ran_gamma function now uses the Marsaglia-Tsang fast gamma
    method of gsl_ran_gamma_mt by default.
  * The matrix and vector min/max functions now always propagate any
    NaNs in their input.
  * Prevented NaN occuring for extreme parameters in
    gsl_cdf_fdist_{P,Q}inv and gsl_cdf_beta_{P,Q}inv
  * Corrected error estimates for the angular reduction functions
    gsl_sf_angle_restrict_symm_err and gsl_sf_angle_restrict_pos_err.
  * Corrected an error in the higher digits of M_PI_4 (this was beyond
    the limit of double precision, so double precision results are not
    affected).
  * gsl_root_test_delta now always returns success if two iterates are
    the same, x1==x0.
  * A Japanese translation of the reference manual is now available
    from the GSL webpage at http://www.gnu.org/software/gsl/ thanks to
    Daisuke TOMINAGA.
  * Added new functions for basis splines, see the "Basis Splines"
    chapter in the GSL Reference Manual for details.
  * Added new functions for testing the sign of vectors and matrices,
    gsl_vector_ispos, gsl_vector_isneg, gsl_matrix_ispos and
    gsl_matrix_isneg.
  * Fixed a bug in gsl_sf_lnpoch_e and gsl_sf_lnpoch_sgn_e which caused
    the incorrect value 1.0 instead of 0.0 to be returned for x==0.
  * Fixed cancellation error in gsl_sf_laguerre_n for n > 1e7 so that
    larger arguments can be calculated without loss of precision.
  * Improved gsl_sf_zeta_e to return exactly zero for negative even
    integers, avoiding less accurate trigonometric reduction.
  * Fixed a bug in gsl_sf_zetam1_int_e where 0 was returned instead of
  - 1 for negative even integer arguments.
  * When the differential equation solver gsl_odeiv_apply encounters a
    singularity it returns the step-size which caused the error code from
    the user-defined function, as opposed to leaving the step-size
    unchanged.
  * Added support for nonsymmetric eigensystems
  * Added Mathieu functions
* Wed Feb  7 2007 garloff@suse.de
- -l2h and BuildRequire latex2html for formulas in manual (#242160).
* Thu Nov 23 2006 garloff@suse.de
- -momit-leaf-frame-pointer was only enabled on x86_64 and i386;
  however, it should have been enabled on all ix86. Fixed.
* Mon Oct 16 2006 garloff@suse.de
- Don't use -ffast-math any more (-ffast-math was enabled on x86,
  x86-64) as otherwise we get inexact (8e-8) results with latest
  compiler for log1p(1e-10), div by zero, SVD.
* Fri Aug 25 2006 garloff@suse.de
- Update to gsl-1.8.
- Enable make check in build process.
* Mon Feb 20 2006 stbinner@suse.de
- make gsl-devel depend on gsl
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Mon Dec 19 2005 garloff@suse.de
- Split package into gsl and gsl-devel.
- Update to gsl-1.7:
  * Various speedups, accuracy improvements and fixes.
* Mon Apr 25 2005 coolo@suse.de
- fix library dependencies - at least needed for prelink
* Mon Jan 31 2005 ro@suse.de
- adapted to texi2html changes
* Thu Jan 20 2005 garloff@suse.de
- Remove -momit-frame-pointer from most archs, the compiler does
  not support it there.
* Wed Jan 19 2005 garloff@suse.de
- Avoid uninitialized variables, and fix a size_t vs. unsigned
  int issue.
- Update to gsl-1.6:
  * Wavelet functions
  * LQ decomposition
  * Various bugfixes and minor improvements (SYRK, HERK,
    swap_vectors, cheb_eval_n_err, sf_gamma_inc, cspline,
    akima, ode-initval, sf_psi_1, sf_expint_Ei_e, cdf_beta_X,
    eigen_jacobi, error stream flushes prior to abort).
* Fri Aug 20 2004 garloff@suse.de
- Fix build on non-x86/x86-64 (no -monit-leaf-frame-pointer).
- Allow parallel build.
* Sat Aug 14 2004 garloff@suse.de
- Update to version 1.5.
- More aggressive compiler optimization flags.
* Tue May 18 2004 ro@suse.de
- use -fno-strict-aliasing
* Wed Feb 25 2004 stepan@suse.de
- update to version 1.4
* Sat Jan 10 2004 adrian@suse.de
- add %%defattr
* Tue May 27 2003 ro@suse.de
- add pkgconfig file to filelist
* Wed Jan 15 2003 garloff@suse.de
- bzip2 sources
* Wed Jan 15 2003 garloff@suse.de
- Update to gsl-1.3:
  * Fixed gsl_sf_coupling
  * exponential integral exp(-x)*Ei(x)
  * many bugfixes
- Update to gsl-1.2:
  * new functions for combining permutations etc.
  * multiroot functions
  * dflt error handler outputs message before aborting
  * gsl_linalg_SV_decomp handles exact zeros now
  * unsymmetric tridiagonal solvers added
  * bugfixes
- Update to gsl-1.1.1:
  * bugfixes
- Update to gsl-1.1:
  * permutation copy function
  * gsl_sf_gamma_inc improved
  * IEEE handling of FP numbers tested in configure
  * gsl_histogram_sum
  * More physical constants (r_B, eps_0)
  * Knuth's random number generators
  * bugfixes
* Fri Jul  5 2002 kukuk@suse.de
- Use %%ix86 macro
* Wed May  8 2002 garloff@suse.de
- Fix %%lib64 issues
- Remove -freduce-all-givs from compiler flags.
* Mon Dec 10 2001 garloff@suse.de
- Creation of gsl-1.0
- Produce and install HTML docu
